@@ -177,10 +177,7 @@ class Streaming(OperatorMixin, core.APIRegisterMixin):
         assert example is not None
         self.example = example
         if not isinstance(self.example, self._subtype):
-            msg = ("For streaming type %s we expect an example of type %s. "
-                   "Got %s") % (type(self).__name__, self._subtype.__name__,
-                                str(self.example))
-            raise TypeError(msg)
+            self.example = self._subtype(example)
         assert isinstance(self.example, self._subtype)
         self.stream = stream or Stream()
         if stream_type:
@@ -239,8 +236,17 @@ class Streaming(OperatorMixin, core.APIRegisterMixin):
         self.stream.stop()
 
     def _ipython_display_(self, **kwargs):
-        return self.stream.latest().rate_limit(
-            0.5).gather()._ipython_display_(**kwargs)
+        try:
+            from ipywidgets import Output  # noqa: F401
+            return self.stream.latest().rate_limit(
+                0.5).gather()._ipython_display_(**kwargs)
+        except ImportError:
+            # since this function is only called by jupyter, this import must succeed
+            from IPython.display import display, HTML
+            if hasattr(self, '_repr_html_'):
+                return display(HTML(self._repr_html_()))
+            else:
+                return display(self.__repr__())
 
     def emit(self, x):
         self.verify(x)
